@@ -612,7 +612,7 @@ drag_data_get (GtkWidget *widget, GdkDragContext *context, GtkSelectionData *sel
 			skstore->priv->drag_destination = g_path_get_dirname (destination);
 			g_free (destination);
 		
-			gtk_selection_data_set (selection_data, selection_data->target, 8, (guchar*)"S", 1);
+			gtk_selection_data_set (selection_data, gtk_selection_data_get_target (selection_data), 8, (guchar*)"S", 1);
 			ret = TRUE;
 		}
 		
